pub enum InterruptMode {
IM0,
IM1,
IM2,
}Expand description
The U880 maskable-interrupt response mode, selected by the IM 0/1/2
instructions.
Variants
IM0
Mode 0: execute an instruction placed on the data bus by the device.
IM1
Mode 1: restart to 0x0038.
IM2
Mode 2: vectored interrupt through the table pointed to by register I.